searchData={"items":[{"type":"module","title":"Powex","doc":"Proof of Work implementation using Rust NIF for high-performance mining.\n\nThis module provides functions to compute and validate Proof of Work using SHA-256 hashing.\nThe implementation uses Rust for performance-critical operations.","ref":"Powex.html"},{"type":"function","title":"Powex.compute/2","doc":"Computes a Proof of Work nonce for the given data and difficulty.","ref":"Powex.html#compute/2"},{"type":"function","title":"Parameters - Powex.compute/2","doc":"- `data`: The input data (string or binary) to hash\n- `difficulty`: Number of leading zeros required in the hash (integer)","ref":"Powex.html#compute/2-parameters"},{"type":"function","title":"Returns - Powex.compute/2","doc":"- `{:ok, nonce}` when a valid nonce is found\n- `{:error, reason}` if computation fails","ref":"Powex.html#compute/2-returns"},{"type":"function","title":"Examples - Powex.compute/2","doc":"iex> {:ok, nonce} = Powex.compute(\"hello world\", 4)\n    iex> is_integer(nonce)\n    true\n\n    iex> Powex.compute(\"\", 0)\n    {:ok, 0}","ref":"Powex.html#compute/2-examples"},{"type":"function","title":"Powex.compute_parallel/3","doc":"Computes a Proof of Work nonce using parallel processing for improved performance.","ref":"Powex.html#compute_parallel/3"},{"type":"function","title":"Parameters - Powex.compute_parallel/3","doc":"- `data`: The input data (string or binary) to hash\n- `difficulty`: Number of leading zeros required in the hash (integer)\n- `threads`: Number of threads to use for parallel computation (default: number of CPU cores)","ref":"Powex.html#compute_parallel/3-parameters"},{"type":"function","title":"Returns - Powex.compute_parallel/3","doc":"- `{:ok, nonce}` when a valid nonce is found\n- `{:error, reason}` if computation fails","ref":"Powex.html#compute_parallel/3-returns"},{"type":"function","title":"Examples - Powex.compute_parallel/3","doc":"iex> {:ok, nonce} = Powex.compute_parallel(\"hello world\", 4, 4)\n    iex> is_integer(nonce)\n    true","ref":"Powex.html#compute_parallel/3-examples"},{"type":"function","title":"Powex.get_hash/2","doc":"Gets the hash for given data and nonce combination.","ref":"Powex.html#get_hash/2"},{"type":"function","title":"Parameters - Powex.get_hash/2","doc":"- `data`: The input data (string or binary)\n- `nonce`: The nonce value (integer)","ref":"Powex.html#get_hash/2-parameters"},{"type":"function","title":"Returns - Powex.get_hash/2","doc":"- `{:ok, hash}` where hash is the SHA-256 hash as a hex string\n- `{:error, reason}` if hashing fails","ref":"Powex.html#get_hash/2-returns"},{"type":"function","title":"Examples - Powex.get_hash/2","doc":"iex> {:ok, hash} = Powex.get_hash(\"test\", 123)\n    iex> String.length(hash)\n    64","ref":"Powex.html#get_hash/2-examples"},{"type":"function","title":"Powex.valid?/3","doc":"Validates if a nonce produces a valid Proof of Work for the given data and difficulty.","ref":"Powex.html#valid?/3"},{"type":"function","title":"Parameters - Powex.valid?/3","doc":"- `data`: The input data (string or binary) that was hashed\n- `nonce`: The nonce value to validate (integer)\n- `difficulty`: Number of leading zeros required in the hash (integer)","ref":"Powex.html#valid?/3-parameters"},{"type":"function","title":"Returns - Powex.valid?/3","doc":"- `true` if the nonce is valid for the given difficulty\n- `false` if the nonce is invalid","ref":"Powex.html#valid?/3-returns"},{"type":"function","title":"Examples - Powex.valid?/3","doc":"iex> {:ok, nonce} = Powex.compute(\"test data\", 3)\n    iex> Powex.valid?(\"test data\", nonce, 3)\n    true\n\n    iex> Powex.valid?(\"test data\", 12345, 3)\n    false","ref":"Powex.html#valid?/3-examples"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.1"}}